==> vuetify-1.0.8.tgz: package/BACKERS.md <==
# Backers

You can join them in supporting Vuetify.js by [pledging on Patreon](https://www.patreon.com/vuetify)

### $500+
- [LMAX Exchange](https://www.lmax.com/)
- [Intygrate](http://intygrate.com/)

### $250+
- [Eikos Partners](http://www.eikospartners.com/)
- [rateGenius](https://application.rategenius.com/)
- [quitt](https://quitt.ch/)

### $100+
- [Anthony Gherghetta](https://gorilladash.com/)

### $50+
- [Xavier Escoté](http://www.deister.net/)
- [Steve Gehrman](https://cocoatech.com/)
- [Cycloid](https://www.cycloid.io/)
- [LiveCasino](https://livecasino.com/)
- [Nate Controls](http://www.natecontrols.com/)
- [Trek10](https://www.trek10.com/)
- [Zweidenker](http://zweidenker.de)

### $20+
- Tibor Nagy
- [Jaime Olmo](https://www.jaimeolmo.com)
- Michael Marti
- [Aeroden](https://www.aeroden.com)
- Sam Mitchell
- David Hess
- Jay Blanchard
- Christo Crampton
- Team Of Monkeys
- Robin Paolini
- [Integra CCS](https://www.integraccs.com/)
- Joel Hatch
- Pierre Vanhulst
- David Briscese
- Juha Vehnia

### $10+
- Kevin Pilard
- Espen Bratberg
- Ivan Vedernikov
- Chava Sobreyra
- Costa Huang
- Paul
- Jussi Pesonen
- Jordan Wood
- Alexey Toroshchin
- Phillippe Genois
- Jim O\`Quinn
- Sam Bosell
- Cliff Hess
- Antonio Luis Gil Rodríguez
- Omar Spira
- Jiří Žižka
- Dejan Kovac
- Anythony Estebe
- Luis F Rocha
- Eeico Wentrup
- Mathieu Boyer
- Chris Britton
- Matthew O'Leary
- Mike Margerum
- Reto Aebersold
- Mark Freedman
- Fernando Rosentalski Neto
- Eric Nguyen
- Alvin Wang
- Jadranko Dragoje
- Charles McKeever
- Caleb Blankemeyer
- Nicholas Coates
- Stanislovas Janonis
- Nico Rogers
- Jamie Sartell
- Brandon Deo
- Chanlito Hem
- Idea Junction Ltd.
- Michael Hipp
- Keyur Desai
- Phillipp Naderer-Puiu

==> vuetify-1.1.17.tgz: package/BACKERS.md <==
# Backers

You can join them in supporting Vuetify.js by [pledging on Patreon](https://www.patreon.com/vuetify)

### $500+
- [LMAX Exchange](https://www.lmax.com/)
- [Intygrate](http://intygrate.com/)
- [Resale AI](http://resaleai.com/)

### $250+
- [Eikos Partners](http://www.eikospartners.com/)
- [rateGenius](https://application.rategenius.com/)
- [quitt](https://quitt.ch/)
- [DigitalMaas](https://www.digitalmaas.com/)

### $100+
- [Anthony Gherghetta](https://gorilladash.com/)

### $50+
- [Xavier Escoté](http://www.deister.net/)
- [Steve Gehrman](https://cocoatech.com/)
- [Cycloid](https://www.cycloid.io/)
- [Nate Controls](http://www.natecontrols.com/) <!-- Brad Stewart -->
- [Zweidenker](http://zweidenker.de) <!-- Christian Denker -->
- [Software IDM](https://softwareidm.com/) <!-- Peter Sidebotham -->
- [Hohenstein Laboratories](https://www.hohenstein.de/en/home/home.xhtml)
- [P2L Technologies](https://p2l.tech/) <!-- Blaise Laflamme -->
- Terence Tsang

### $20+
- Michael Marti
- [Aeroden](https://www.aeroden.com) <!-- Adrian Belovic -->
- Sam Mitchell
- David Hess
- Jay Blanchard
- Christo Crampton
- Team Of Monkeys
- Robin Paolini
- [Integra CCS](https://www.integraccs.com/)
- Joel Hatch
- David Briscese
- Juha Vehnia
- Max Hodges
- Kent Johnson
- Working Group Two

### $10+
- Kevin Pilard
- Espen Bratberg
- Ivan Vedernikov
- Chava Sobreyra
- Costa Huang
- Paul
- Jordan Wood
- Alexey Toroshchin
- Phillippe Genois
- Sam Bosell
- Cliff Hess
- Omar Spira
- Jiří Žižka
- Dejan Kovac
- Anythony Estebe
- Luis F Rocha
- Eeico Wentrup
- Chris Britton
- Matthew O'Leary
- Mike Margerum
- Reto Aebersold
- Mark Freedman
- Fernando Rosentalski Neto
- Eric Nguyen
- Alvin Wang
- Jadranko Dragoje
- Charles McKeever
- Stanislovas Janonis
- Brandon Deo
- Idea Junction Ltd.
- Michael Hipp
- Keyur Desai
- Casey Dwyer
- Bohdan Kokotko
- Blaine Landowski
- Paul Whittemore
- Alexander Weiher
- Helmi
- Hexodus
- Pierre Vanhulst
- Brett Lindenberg
- Randall Adams
- Andrew Harvey
- Cảnh Kiều
- Dave Willenberg
- James Chang
- Maxence Rose
- Omar Abu Samra
- MEHMET SAGLAM
- bizzy.tv
- Philipp Naderer-Puiu
